pub enum Export {
Procedure(Procedure),
Constant(Constant),
Type(TypeDecl),
Alias(Alias),
}Expand description
Represents an exportable item from a crate::ast::Module.
Variants
Procedure(Procedure)
A locally-defined procedure.
Constant(Constant)
A locally-defined constant.
Type(TypeDecl)
A locally-defined type.
Alias(Alias)
An alias for an externally-defined item, i.e. a re-exported import.
Implementations
Sourceimpl Export
impl Export
Sourcepub fn with_docs(self, docs: Option<Span<String>>) -> Export
pub fn with_docs(self, docs: Option<Span<String>>) -> Export
Adds documentation to this export.
Sourcepub fn attributes(&self) -> Option<&AttributeSet>
pub fn attributes(&self) -> Option<&AttributeSet>
Returns the attributes for this item, if it is a procedure.
Sourcepub fn visibility(&self) -> Visibility
pub fn visibility(&self) -> Visibility
Returns the visibility of this item (e.g. public or private).
See Visibility for more details on what visibilities are supported.
Sourcepub fn signature(&self) -> Option<&FunctionType>
pub fn signature(&self) -> Option<&FunctionType>
Returns a reference to the type signature of this item, if it is a procedure, and known.
Sourcepub fn num_locals(&self) -> usize
pub fn num_locals(&self) -> usize
Returns the number of automatically-allocated words of memory this item requires for the storage of temporaries/local variables.
NOTE: This is only applicable for procedure items - the value 0 will be returned if this is a non-procedure item, or if the type of item is not yet known.
Sourcepub fn unwrap_procedure(&self) -> &Procedure
pub fn unwrap_procedure(&self) -> &Procedure