pub enum PathComponent<'a> {
Root,
Normal(&'a str),
}Expand description
Represents a single component of a Path
Variants
Root
The root anchor, indicating that the path is absolute/fully qualified
Normal(&'a str)
A normal component of the path, i.e. an identifier
Implementations
Sourceimpl<'a> PathComponent<'a>
impl<'a> PathComponent<'a>
Sourcepub fn as_str(&self) -> &'a str
pub fn as_str(&self) -> &'a str
Get this component as a str
NOTE: If the component is quoted, the resulting string does not contain quotes. Depending
on how the resulting string is used, you may need to ensure quotes are added manually. In
general, the Path/PathBuf APIs handle this for you.
Sourcepub fn to_ident(&self) -> Option<Ident>
pub fn to_ident(&self) -> Option<Ident>
Get this component as an Ident, if it represents an identifier
Sourcepub fn requires_quoting(&self) -> bool
pub fn requires_quoting(&self) -> bool
Returns true if this path component requires quoting when displayed/stored as a string