pub struct Iter<'a> { /* private fields */ }Expand description
Returns an iterator over the path components represented in the provided source.
A path consists of at list of components separated by :: delimiter. A path must contain
at least one component. Path components may be quoted, in which :: delimiters are ignored.
Quoted path components may also contain characters that are not otherwise valid identifiers in
Miden Assembly.
Note that quoted components may not contain nested quotes - the appearance of a nested quote in a quoted component will be treated as a closing quote resulting in unexpected behavior or validation errors as a result.
Errors
Returns an error if:
- The path is empty.
- Any component of the path is empty.
- Any quoted component is missing a closing/opening quote (depending on order of iteration)
- Any unquoted component is not a valid identifier (quoted or unquoted) in Miden Assembly
syntax, i.e. starts with an ASCII alphabetic character, contains only printable ASCII
characters, except for
::, which must only be used as a path separator.
Implementations