pub struct Alias {
pub uses: usize,
/* private fields */
}Expand description
Represents an item that acts like it is locally-defined, but is actually externally-defined.
These “aliases” do not have a concrete representation in the module, but are instead resolved during compilation to refer directly to the aliased item.
Fields
uses: usizeThe number of times this import has been used locally.
Implementations
Sourceimpl Alias
impl Alias
Sourcepub fn new(visibility: Visibility, name: Ident, target: AliasTarget) -> Alias
pub fn new(visibility: Visibility, name: Ident, target: AliasTarget) -> Alias
Creates a new item alias called name, which resolves to target.
Sourcepub const fn visibility(&self) -> Visibility
pub const fn visibility(&self) -> Visibility
Returns the visibility of this alias
Sourcepub fn name(&self) -> &Ident
pub fn name(&self) -> &Ident
Returns the name of this alias within its containing module.
If the item is simply re-exported with the same name, this will be equivalent to
self.target().name
Sourcepub fn target(&self) -> &AliasTarget
pub fn target(&self) -> &AliasTarget
Returns the target of this alias
Sourcepub fn target_mut(&mut self) -> &mut AliasTarget
pub fn target_mut(&mut self) -> &mut AliasTarget
Returns a mutable reference to the target of this alias
Sourcepub fn is_absolute(&self) -> bool
pub fn is_absolute(&self) -> bool
Returns true if this alias uses an absolute target path
Sourcepub fn is_renamed(&self) -> bool
pub fn is_renamed(&self) -> bool
Returns true if this alias uses a different name than the target