DebugVarInfo

Struct DebugVarInfo 

pub struct DebugVarInfo { /* private fields */ }
Debug information for tracking a source-level variable.

This record provides debuggers with information about where a variable’s value can be found at a particular point in the program execution.

Implementations

Source

impl DebugVarInfo

pub fn new( name: impl Into<Arc<str>>, value_location: DebugVarLocation, ) -> DebugVarInfo

Creates a new DebugVarInfo with the specified variable name and location.

pub fn name(&self) -> &Arc<str>

Returns the variable name.

pub fn ty(&self) -> Option<&Type>

Returns the type ID if set.

pub fn declared_type(&self) -> Option<Arc<TypeExpr>>

Returns the type ID if set.

pub fn set_ty(&mut self, ty: Type, declared_type: Option<Arc<TypeExpr>>)

Sets the type ID for this variable.

pub fn arg_index(&self) -> Option<NonZero<u32>>

Returns the argument index if this is a function parameter. The index is 1-based.

pub fn set_arg_index(&mut self, arg_index: u32)

Sets the argument index for this variable.

Panics

Panics if arg_index is 0, since argument indices are 1-based.

pub fn location(&self) -> Option<&Location>

Returns the source location if set. This is only set when the location differs from the AssemblyOp location.

pub fn set_location(&mut self, location: Location)

Sets the source location for this variable. Only set this when the location differs from the AssemblyOp location to avoid package bloat.

pub fn value_location(&self) -> &DebugVarLocation

Returns where the variable’s value can be found.

pub fn set_value_location(&mut self, value_location: DebugVarLocation)

Replaces the value location in-place, preserving all other fields.