pub struct EnumType { /* private fields */ }Expand description
A combined type alias and constant declaration corresponding to a C-like enumeration.
C-style enumerations are effectively a type alias for an integer type with a limited set of valid values with associated names (referred to as variants of the enum type).
In Miden Assembly, these provide a means for a procedure to declare that it expects an argument of the underlying integral type, but that values other than those of the declared variants are illegal/invalid. Currently, these are unchecked, and are only used to convey semantic information. In the future, we may perform static analysis to try and identify invalid instances of the enumeration when derived from a constant.
Implementations
Sourceimpl EnumType
impl EnumType
Sourcepub fn new(
visibility: Visibility,
name: Ident,
ty: Type,
variants: impl IntoIterator<Item = Variant>,
) -> EnumType
pub fn new( visibility: Visibility, name: Ident, ty: Type, variants: impl IntoIterator<Item = Variant>, ) -> EnumType
Construct a new enum type with the given name and variants
The caller is assumed to have already validated that ty is an integral type, and this
function will assert that this is the case.
Sourcepub fn with_docs(self, docs: Option<Span<String>>) -> EnumType
pub fn with_docs(self, docs: Option<Span<String>>) -> EnumType
Adds documentation to this enum declaration.
Sourcepub fn with_span(self, span: SourceSpan) -> EnumType
pub fn with_span(self, span: SourceSpan) -> EnumType
Override the default source span
Sourcepub fn is_c_like(&self) -> bool
pub fn is_c_like(&self) -> bool
Returns true if this is a C-style enum where the discriminant is the value
Sourcepub fn set_span(&mut self, span: SourceSpan)
pub fn set_span(&mut self, span: SourceSpan)
Set the source span
Sourcepub const fn visibility(&self) -> Visibility
pub const fn visibility(&self) -> Visibility
Get the visibility of this enum type
Sourcepub fn variants_mut(&mut self) -> &mut Vec<Variant>
pub fn variants_mut(&mut self) -> &mut Vec<Variant>
Get the variants of this enum type, mutably
Sourcepub fn into_parts(self) -> (TypeAlias, Vec<Variant>)
pub fn into_parts(self) -> (TypeAlias, Vec<Variant>)
Split this definition into its type alias and variant parts