pub struct SourceSpan { /* private fields */ }Expand description
This represents a span of bytes in a Miden Assembly source file.
It is compact, using only 8 bytes to represent the full span. This does, however, come at the tradeoff of only supporting source files of up to 2^32 bytes.
This type is produced by the lexer and carried through parsing. It can be converted into a line/column range as well, if needed.
This representation is more convenient to produce, and allows showing source spans in error messages, whereas line/column information is useful at a glance in debug output, it is harder to produce nice errors with it compared to this representation.
Implementations
Sourceimpl SourceSpan
impl SourceSpan
Sourcepub const UNKNOWN: SourceSpan
pub const UNKNOWN: SourceSpan
A sentinel SourceSpan that indicates the span is unknown/invalid
Sourcepub const SYNTHETIC: SourceSpan
pub const SYNTHETIC: SourceSpan
A sentinel SourceSpan that indicates compiler-generated/synthetic code
This is used to distinguish between:
- UNKNOWN: debug info missing or failed to parse from DWARF
- SYNTHETIC: compiler-generated code that doesn’t correspond to any user source
Sourcepub fn new<B>(source_id: SourceId, range: Range<B>) -> SourceSpan
pub fn new<B>(source_id: SourceId, range: Range<B>) -> SourceSpan
Creates a new SourceSpan from the given range.
Sourcepub fn at(source_id: SourceId, offset: impl Into<ByteIndex>) -> SourceSpan
pub fn at(source_id: SourceId, offset: impl Into<ByteIndex>) -> SourceSpan
Creates a new SourceSpan for a specific offset.
Sourcepub fn try_from_range(
source_id: SourceId,
range: Range<usize>,
) -> Result<SourceSpan, InvalidByteIndexRange>
pub fn try_from_range( source_id: SourceId, range: Range<usize>, ) -> Result<SourceSpan, InvalidByteIndexRange>
Try to create a new SourceSpan from the given range with usize bounds.
Sourcepub const fn is_unknown(&self) -> bool
pub const fn is_unknown(&self) -> bool
Returns true if this SourceSpan represents the unknown span
Sourcepub const fn is_synthetic(&self) -> bool
pub const fn is_synthetic(&self) -> bool
Returns true if this SourceSpan represents synthetic/compiler-generated code
Sourcepub fn set_source_id(&mut self, id: SourceId)
pub fn set_source_id(&mut self, id: SourceId)
Manually set the SourceId associated with this source span
This is useful in cases where the range of the span is known, but the source id itself is not available yet, due to scope or some other limitation. In such cases you might wish to visit parsed objects once the source id is available, and update all of their spans accordingly.
Sourcepub fn start(&self) -> ByteIndex
pub fn start(&self) -> ByteIndex
Gets the offset in bytes corresponding to the start of this span (inclusive).
Sourcepub fn end(&self) -> ByteIndex
pub fn end(&self) -> ByteIndex
Gets the offset in bytes corresponding to the end of this span (exclusive).
Sourcepub fn into_range(self) -> Range<u32> ⓘ
pub fn into_range(self) -> Range<u32> ⓘ
Converts this span into a Range<u32>.
Sourcepub fn into_slice_index(self) -> Range<usize> ⓘ
pub fn into_slice_index(self) -> Range<usize> ⓘ
Converts this span into a Range<usize>.