pub struct EnumType { /* private fields */ }Expand description
An enum type is a special type that takes one of two forms:
- C-like enumeration of named integer values, where the discriminant is the integral type
- Rust-like enumeration over the variant types, tagged with a value of the discriminant type
In 1, the variants are all of the same type as the discriminant. In 2, the variants may each be different shape.
Implementations
Sourceimpl EnumType
impl EnumType
Sourcepub fn new<I>(
name: Arc<str>,
discriminant: Type,
variants: I,
) -> Result<EnumType, InvalidEnumTypeError>where
I: IntoIterator<Item = Variant>,
pub fn new<I>(
name: Arc<str>,
discriminant: Type,
variants: I,
) -> Result<EnumType, InvalidEnumTypeError>where
I: IntoIterator<Item = Variant>,
Construct a new EnumType with the given name, discriminant type, and variants.
Sourcepub fn phantom(
name: Arc<str>,
discriminant: Type,
) -> Result<EnumType, InvalidEnumTypeError>
pub fn phantom( name: Arc<str>, discriminant: Type, ) -> Result<EnumType, InvalidEnumTypeError>
Construct a new EnumType representing a phantom type with the given name and discriminant
Sourcepub fn discriminant(&self) -> &Type
pub fn discriminant(&self) -> &Type
Returns the discriminant type for this enum
Sourcepub fn variant_offsets(&self) -> impl ExactSizeIterator
pub fn variant_offsets(&self) -> impl ExactSizeIterator
Returns an iterator over the variants of this enumeration with their offset from the base of the enum (i.e. given a pointer to a value of this type, the offset can be used to derive a pointer to the variant value type).
Sourcepub fn discriminant_values(&self) -> impl ExactSizeIterator
pub fn discriminant_values(&self) -> impl ExactSizeIterator
Returns an iterator over the discriminant values of this enum.
The order of values produced by this iterator is identical to the order of the variants.
Discriminant values are computed as follows:
- Variants either have an explicit discriminant value set, or receive a discriminant value
derived from the preceding variant by adding
1to it. - If the first variant has no explicit value, the discriminant value range begins at
0. - If the the end of the valid discriminant value range is reached before the last variant, this function will panic with an assertion pointing to the invalid variant.
Sourcepub fn is_phantom(&self) -> bool
pub fn is_phantom(&self) -> bool
Returns true if this type has no variants, and thus no physical in-memory representation.
Sourcepub fn is_zst(&self) -> bool
pub fn is_zst(&self) -> bool
Returns true if this type has no physical in-memory representation, i.e. it is a phantom
Sourcepub fn is_c_like(&self) -> bool
pub fn is_c_like(&self) -> bool
Returns true if this enum type is a C-like enum, i.e. where the type is equivalent to the discriminant value type.
Sourcepub fn size_in_bytes(&self) -> usize
pub fn size_in_bytes(&self) -> usize
Returns the size in bytes of this type, without alignment padding.
Sourcepub fn size_in_bits(&self) -> usize
pub fn size_in_bits(&self) -> usize
Returns the size in bits of this type, without alignment padding.
Sourcepub fn min_alignment(&self) -> usize
pub fn min_alignment(&self) -> usize
Returns the minimum alignment, in bytes, of this type