Rodata

Struct Rodata 

pub struct Rodata {
    pub component: ComponentId,
    pub digest: Word,
    pub start: NativePtr,
    pub data: Arc<ConstantData>,
}
Represents a read-only data segment, combined with its content digest

Fields

component: ComponentId

The component to which this read-only data segment belongs

digest: Word

The content digest computed for data

start: NativePtr

The address at which the data for this segment begins

data: Arc<ConstantData>

The raw binary data for this segment

Implementations

Source

impl Rodata

pub fn size_in_bytes(&self) -> usize

pub fn size_in_felts(&self) -> usize

pub fn size_in_words(&self) -> usize

pub fn to_elements(&self) -> Vec<Felt>

Attempt to convert this rodata object to its equivalent representation in felts

See Self::bytes_to_elements for more details.

pub fn bytes_to_elements(bytes: &[u8]) -> Vec<Felt>

Attempt to convert the given bytes to their equivalent representation in felts

The resulting felts will be in padded out to the nearest number of words, i.e. if the data only takes up 3 felts worth of bytes, then the resulting Vec will contain 4 felts, so that the total size is a valid number of words.