pub struct DebugVarInfo { /* private fields */ }Expand description
Debug information for tracking a source-level variable.
This record provides debuggers with information about where a variable’s value can be found at a particular point in the program execution.
Implementations
Sourceimpl DebugVarInfo
impl DebugVarInfo
Sourcepub fn new(
name: impl Into<Arc<str>>,
value_location: DebugVarLocation,
) -> DebugVarInfo
pub fn new( name: impl Into<Arc<str>>, value_location: DebugVarLocation, ) -> DebugVarInfo
Creates a new DebugVarInfo with the specified variable name and location.
Sourcepub fn declared_type(&self) -> Option<Arc<TypeExpr>>
pub fn declared_type(&self) -> Option<Arc<TypeExpr>>
Returns the type ID if set.
Sourcepub fn set_ty(&mut self, ty: Type, declared_type: Option<Arc<TypeExpr>>)
pub fn set_ty(&mut self, ty: Type, declared_type: Option<Arc<TypeExpr>>)
Sets the type ID for this variable.
Sourcepub fn arg_index(&self) -> Option<NonZero<u32>>
pub fn arg_index(&self) -> Option<NonZero<u32>>
Returns the argument index if this is a function parameter. The index is 1-based.
Sourcepub fn set_arg_index(&mut self, arg_index: u32)
pub fn set_arg_index(&mut self, arg_index: u32)
Sets the argument index for this variable.
Panics
Panics if arg_index is 0, since argument indices are 1-based.
Sourcepub fn location(&self) -> Option<&Location>
pub fn location(&self) -> Option<&Location>
Returns the source location if set. This is only set when the location differs from the AssemblyOp location.
Sourcepub fn set_location(&mut self, location: Location)
pub fn set_location(&mut self, location: Location)
Sets the source location for this variable. Only set this when the location differs from the AssemblyOp location to avoid package bloat.
Sourcepub fn value_location(&self) -> &DebugVarLocation
pub fn value_location(&self) -> &DebugVarLocation
Returns where the variable’s value can be found.
Sourcepub fn set_value_location(&mut self, value_location: DebugVarLocation)
pub fn set_value_location(&mut self, value_location: DebugVarLocation)
Replaces the value location in-place, preserving all other fields.