pub trait ToMasmComponent {
// Required method
fn to_masm_component(
&self,
analysis_manager: AnalysisManager,
) -> Result<MasmComponent, Report>;
}Expand description
This trait represents a conversion pass from some HIR entity to a Miden Assembly component.
Required Methods
fn to_masm_component( &self, analysis_manager: AnalysisManager, ) -> Result<MasmComponent, Report>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ToMasmComponent for Component
1:1 conversion from HIR component to MASM component
impl ToMasmComponent for Component
1:1 conversion from HIR component to MASM component
fn to_masm_component( &self, analysis_manager: AnalysisManager, ) -> Result<MasmComponent, Report>
Sourceimpl ToMasmComponent for World
Derivation of a MASM component from an HIR world
impl ToMasmComponent for World
Derivation of a MASM component from an HIR world
This currently works by treating all definition-carrying modules in the world as part of a single logical component.