ToMasmComponent

Trait ToMasmComponent 

pub trait ToMasmComponent {
    // Required method
    fn to_masm_component(
        &self,
        analysis_manager: AnalysisManager,
    ) -> Result<MasmComponent, Report>;
}
This trait represents a conversion pass from some HIR entity to a Miden Assembly component.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToMasmComponent for Component

1:1 conversion from HIR component to MASM component

Source

impl ToMasmComponent for World

Derivation of a MASM component from an HIR world

This currently works by treating all definition-carrying modules in the world as part of a single logical component.

Implementors